Python: module share

share (version 0.0.2) | index share.py

`This tools run scripts and display the result in a Web Interface.
This file download and upload functions for scripts,
tools and command line client.`

Modules
`` |  |
json | os | ntpath | sys

Classes
`` |  | builtins.object Download
class Download(builtins.object)
`` | `This class implement download functions for filename or ID.`
| Methods defined here: filename(environ: os._Environ, user: ~User, server_configuration: ~ServerConfiguration, filename: str, arguments: List[str], inputs: List[str], csrf_token: str = None) -> Tuple[str, Dict[str, str], str] `This funtion download file by filename.` id(environ: os._Environ, user: ~User, server_configuration: ~ServerConfiguration, id_: str, arguments: List[str], inputs: List[str], csrf_token: str = None) -> Tuple[str, Dict[str, str], str] `This funtion download file by ID.` Static methods defined here: get_data(file: uploads_management.Upload) -> bytes `This function get file and manage the compression.` Data descriptors defined here: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`

Functions
`` |  | upload(environ: os._Environ, user: ~User, server_configuration: ~ServerConfiguration, filename: str, data: bytes, none: None, csrf_token: str = None) -> Tuple[str, Dict[str, str], str] `This funtion upload file.`

Data
`` |  | Dict = typing.Dict List = typing.List ServerConfiguration = ~ServerConfiguration Tuple = typing.Tuple User = ~User __author_email__ = 'mauricelambert434@gmail.com' __copyright__ = '\nWebScripts Copyright (C) 2021 Maurice Lambert...ome to redistribute it\nunder certain conditions.\n' __description__ = '\nThis tools run scripts and display the result i...tions for scripts,\ntools and command line client.' __license__ = 'GPL-3.0 License' __maintainer__ = 'Maurice Lambert' __maintainer_email__ = 'mauricelambert434@gmail.com' __url__ = 'https://github.com/mauricelambert/WebScripts' base_path = [r'C:\Users\CSU1\Documents\dev\modules\WebScripts\WebScripts\modules', '..'] copyright = '\nWebScripts Copyright (C) 2021 Maurice Lambert...ome to redistribute it\nunder certain conditions.\n' license = 'GPL-3.0 License'

Author
`` |  | Maurice Lambert